pub struct ImageCacheFactoryImpl {
broken_image_icon_data: Arc<Vec<u8>>,
thread_pool: Arc<ThreadPool>,
fontdb: Arc<Database>,
}Fields
broken_image_icon_data: Arc<Vec<u8>>The data to use for the broken image icon used when images cannot load.
thread_pool: Arc<ThreadPool>Thread pool for image decoding
fontdb: Arc<Database>A shared font database to be used by system fonts accessed when rasterizing vector images.
Implementations